"""
Example program to demonstrate Gooey's presentation of subparsers
"""
import shlex

import sys

from gooey import Gooey, GooeyParser, Events
from gooey.python_bindings.constants import TABBED

running = True

with open('t-module-top.txt', 'w') as f:
    f.write(str(sys.argv))

xxx = r""""C:\Users\Chris\Documents\Gooey\venv368\Scripts\python.exe" -u "C:/Users/Chris/Documents/Gooey/gooey/examples/issue785.py" parser1 --textfield "2" --textarea "b'oneline twoline'" --password "hunter42" --commandfield "b'cmdr'" --dropdown "two" --listboxie "Option three" "Option four" -c -c -c -o --mutextwo "mut-2" --filechooser "fc-value" --filesaver "fs-value" --dirchooser "dc-value" --datechooser "2015-01-01" --colourchooser "#000000" --gooey-validate-form --gooey-state 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"""
xxx = shlex.split(xxx)[3:]

@Gooey(
    optional_cols=2,
    program_name="Subparser Demo",
    navigation=TABBED,
    tabbed_groups=True,
    dump_build_config=True,
    show_success_modal=False,
    # cli=xxx,
    use_events=[Events.VALIDATE_FORM]
)
def main():
    parser = GooeyParser()
    subs = parser.add_subparsers(help='commands', dest='command')

    parser_one = subs.add_parser('parser1', prog="Parser 1")
    parser_one.add_argument('--textfield', default=2, widget="TextField", required=True)
    parser_one.add_argument('--textarea', default="oneline twoline", widget='Textarea')
    parser_one.add_argument('--password', default="hunter42", widget='PasswordField')
    parser_one.add_argument('--commandfield', default="cmdr", widget='CommandField')
    parser_one.add_argument('--dropdown',
                        choices=["one", "two"], default="two", widget='Dropdown')
    parser_one.add_argument('--listboxie',
                        nargs='+',
                        default=['Option three', 'Option four'],
                        choices=['Option one', 'Option two', 'Option three',
                                 'Option four'],
                        widget='Listbox',
                        gooey_options={
                            'height': 300,
                            'validate': '',
                            'heading_color': '',
                            'text_color': '',
                            'hide_heading': True,
                            'hide_text': True,
                        }
                        )
    parser_one.add_argument('-c', '--counter', default=3, action='count',
                        widget='Counter')
    #
    parser_one.add_argument("-o", "--overwrite", action="store_true",
                        default=True,
                        widget='CheckBox')

    ### Mutex Group ###
    verbosity = parser_one.add_mutually_exclusive_group(
        required=True,
        gooey_options={
            'initial_selection': 1
        }
    )
    verbosity.add_argument(
        '--mutexone',
        default=True,
        action='store_true',
        help="Show more details")

    verbosity.add_argument(
        '--mutextwo',
        default='mut-2',
        widget='TextField')

    parser_one.add_argument("--filechooser", default="fc-value", widget='FileChooser')
    parser_one.add_argument("--filesaver", default="fs-value", widget='FileSaver')
    parser_one.add_argument("--dirchooser", default="dc-value", widget='DirChooser')
    parser_one.add_argument("--datechooser", default="2015-01-01", widget='DateChooser')
    parser_one.add_argument("--colourchooser", default="#000000", widget='ColourChooser')

    parser_two = subs.add_parser('parser2', prog="parser 2, mah man")
    parser_two.add_argument('textfield', default=2, type=int, widget="TextField")
    parser_two.add_argument('textarea', default="oneline twoline",
                            widget='Textarea')
    parser_two.add_argument('password', default="hunter42", widget='PasswordField')
    parser_two.add_argument('commandfield', default="cmdr", widget='CommandField')
    parser_two.add_argument('dropdown',
                            choices=["one", "two"], default="two", widget='Dropdown')
    parser_two.add_argument('listboxie',
                            nargs='+',
                            default=['Option three', 'Option four'],
                            choices=['Option one', 'Option two', 'Option three',
                                     'Option four'],
                            widget='Listbox',
                            gooey_options={
                                'height': 300,
                                'validate': '',
                                'heading_color': '',
                                'text_color': '',
                                'hide_heading': True,
                                'hide_text': True,
                            }
                            )
    parser_two.add_argument('-c', '--counter', default=3, action='count',
                            widget='Counter')
    #
    parser_two.add_argument("-o", "--overwrite", action="store_true",
                            default=True,
                            widget='CheckBox')

    ### Mutex Group ###
    verbosity = parser_two.add_mutually_exclusive_group(
        required=True,
        gooey_options={
            'initial_selection': 1
        }
    )
    verbosity.add_argument(
        '--mutexone',
        default=True,
        action='store_true',
        help="Show more details")

    verbosity.add_argument(
        '--mutextwo',
        default='mut-2',
        widget='TextField')

    parser_two.add_argument("--filechooser", default="fc-value", widget='FileChooser')
    parser_two.add_argument("--filesaver", default="fs-value", widget='FileSaver')
    parser_two.add_argument("--dirchooser", default="dc-value", widget='DirChooser')
    parser_two.add_argument("--datechooser", default="2015-01-01",widget='DateChooser')
    parser_two.add_argument("--colourchooser", default="#000000", widget='ColourChooser')

    dest_vars = [
        'textfield',
        'textarea',
        'password',
        'commandfield',
        'dropdown',
        'listboxie',
        'counter',
        'overwrite',
        'mutextwo',
        'filechooser',
        'filesaver',
        'dirchooser',
        'datechooser',
        'colourchooser'
    ]

    with open('tmp2.txt', 'w') as f:
        f.write(str(sys.argv))
    args = parser.parse_args()
    import time
    time.sleep(.3)
    for i in dest_vars:
        assert getattr(args, i) is not None
    print("Success")


if __name__ == '__main__':
    main()


from concurrent.futures import ThreadPoolExecutor
from threading import Thread
from typing import Callable, Dict, Any

from gooey.gui import seeder
from gooey.gui import state as s
from gooey.gui.state import FullGooeyState
from gooey.python_bindings.types import Try, PublicGooeyState


def communicateFormValidation(state: FullGooeyState, callback: Callable[[Try[Dict[str, str]]], None]) -> None:
    communicateAsync(s.buildFormValidationCmd(state), state, callback)


def communicateSuccessState(state: FullGooeyState, callback: Callable[[Try[PublicGooeyState]], None]) -> None:
    communicateAsync(s.buildOnSuccessCmd(state), state, callback)


def communicateErrorState(state: FullGooeyState, callback: Callable[[Try[PublicGooeyState]], None]) -> None:
    communicateAsync(s.buildOnErrorCmd(state), state, callback)


def fetchFieldValidation():
    pass



def fetchFieldAction():
    pass

def fetchFormAction():
    pass


def communicateAsync(cmd: str, state: FullGooeyState, callback: Callable[[Any], None]):
    """
    Callable MUST be wrapped in wx.CallAfter if its going to
    modify the UI.
    """
    def work():
        result = seeder.communicate(cmd, state['encoding'])
        callback(result)
    thread = Thread(target=work)
    thread.start()




"""
Python file for Processor test suite

Short 1s loop which purposefully ignores
Keyboard Interrupts in order to continue
executing
"""

import time
import signal

def ignored_it(*args):
    print("INTERRUPT")

signal.signal(signal.SIGBREAK, ignored_it)


while True:
    print(time.time())
    time.sleep(0.1)


from gooey.gui.components.widgets.core.text_input import PasswordInput
from gooey.gui.components.widgets.textfield import TextField
from gooey.python_bindings import types as t

__ALL__ = ('PasswordField',)

class PasswordField(TextField):
    widget_class = PasswordInput  # type: ignore

    def __init__(self, *args, **kwargs):
        super(PasswordField, self).__init__(*args, **kwargs)

    def getUiState(self) -> t.FormField:  # type: ignore
        return t.PasswordField(**super().getUiState())  # type: ignore




"""
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!!!!!!!!DEBUGGING NOTE!!!!!!!!!!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

PyCharm will inject addition params into stdout when starting
a new process. This can make debugging VERY VERY CONFUSING as
the thing being injected starts complaining about unknown
arguments...

TL;DR: disable the "Attaach to subprocess automatically" option
in the Debugger settings, and the world will be sane again.

See: https://youtrack.jetbrains.com/issue/PY-24929
and: https://www.jetbrains.com/help/pycharm/2017.1/python-debugger.html

!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!!!!!!!!DEBUGGING NOTE!!!!!!!!!!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
"""
import json
import os
import sys
import traceback
from argparse import ArgumentParser
from copy import deepcopy
from typing import List, Dict

from gooey.python_bindings.dynamics import monkey_patch_for_form_validation
from gooey.python_bindings.dynamics import patch_argument, collect_errors
from gooey.python_bindings.types import GooeyParams
from gooey.python_bindings.coms import serialize_outbound, decode_payload
from gooey.python_bindings.types import PublicGooeyState
from . import cmd_args
from . import config_generator


def noop(*args, **kwargs):
    """
    No-op for dev/null-ing handlers which
    haven't been specified by the user.
    """
    return None


def bypass_gooey(params):
    """
    Bypasses all the Gooey machinery and runs the user's code directly.
    """
    def parse_args(self: ArgumentParser, args=None, namespace=None):
        # We previously mutated sys.argv directly to remove
        # the --ignore-gooey flag. But this caused lots of issues
        # See: https://github.com/chriskiehl/Gooey/issues/686
        # So, we instead modify the parser to transparently
        # consume the extra token.
        patched_parser = patch_argument(self, '--ignore-gooey', action='store_true')
        args = patched_parser.original_parse_args(args, namespace)  # type: ignore
        # removed from the arg object so the user doesn't have
        # to deal with it or be confused by it
        del args.ignore_gooey
        return args
    return parse_args


def boostrap_gooey(params: GooeyParams):
    """Bootstraps the Gooey UI."""
    def parse_args(self: ArgumentParser, args=None, namespace=None):
        # This import is delayed so it is not in the --ignore-gooey codepath.
        from gooey.gui import bootstrap
        source_path = sys.argv[0]

        build_spec = None
        if params['load_build_config']:
            try:
                exec_dir = os.path.dirname(sys.argv[0])
                open_path = os.path.join(exec_dir, params['load_build_config'])  # type: ignore
                build_spec = json.load(open(open_path, "r"))
            except Exception as e:
                print('Exception loading Build Config from {0}: {1}'.format(params['load_build_config'], e))
                sys.exit(1)

        if not build_spec:
            if params['use_cmd_args']:
                cmd_args.parse_cmd_args(self, args)

            build_spec = config_generator.create_from_parser(
                self,
                source_path,
                **params)

        if params['dump_build_config']:
            config_path = os.path.join(os.path.dirname(sys.argv[0]), 'gooey_config.json')
            print('Writing Build Config to: {}'.format(config_path))
            with open(config_path, 'w') as f:
                f.write(json.dumps(build_spec, indent=2))
        bootstrap.run(build_spec)
    return parse_args


def validate_form(params: GooeyParams, write=print, exit=sys.exit):
    """
    Validates the user's current form.
    """
    def merge_errors(state: PublicGooeyState, errors: Dict[str, str]) -> PublicGooeyState:
        changes = deepcopy(state['active_form'])
        for item in changes:
            if item['type'] == 'RadioGroup':
                for subitem in item['options']:  # type: ignore
                    subitem['error'] = errors.get(subitem['id'], None)
                item['error'] = any(x['error'] for x in item['options'])   # type: ignore
            else:
                item['error'] = errors.get(item['id'], None)  # type: ignore

        return PublicGooeyState(active_form=changes)

    def parse_args(self: ArgumentParser, args=None, namespace=None):
        error_registry: Dict[str, Exception] = {}
        patched_parser = monkey_patch_for_form_validation(error_registry, self)
        try:
            args = patched_parser.original_parse_args(args, namespace)  # type: ignore
            state = args.gooey_state
            next_state = merge_errors(state, collect_errors(patched_parser, error_registry, vars(args)))
            write(serialize_outbound(next_state))
            exit(0)
        except Exception as e:
            write(e)
            exit(1)
    return parse_args


def validate_field(params):
    def parse_args(self: ArgumentParser, args=None, namespace=None):
        raise NotImplementedError
    return parse_args


def handle_completed_run(params, write=print, exit=sys.exit):
    def parse_args(self: ArgumentParser, args=None, namespace=None):
        # because we're running under the context of a successful
        # invocation having just completed, the arguments supplied to
        # the parser to trigger it are thus, by definition, safe to parse.
        # So, we don't need any error patching monkey business and just need
        # to attach our specific arg to parse the extra option Gooey passes

        patch_argument(self, '--gooey-state', action='store', type=decode_payload)
        patch_argument(self, '--gooey-run-is-success', default=False, action='store_true')
        patch_argument(self, '--gooey-run-is-failure', default=False, action='store_true')

        try:
            args = self.original_parse_args(args, namespace)  # type: ignore
            form_state = args.gooey_state
            was_success = args.gooey_run_is_success
            # removing the injected gooey value so as not
            # to clutter the user's object
            del args.gooey_state
            del args.gooey_run_is_success
            del args.gooey_run_is_failure
            if was_success:
                next_state = getattr(self, 'on_gooey_success', noop)(args, form_state)  # type: ignore
            else:
                next_state = getattr(self, 'on_gooey_error', noop)(args, form_state)  # type: ignore
            write(serialize_outbound(next_state))
            exit(0)
        except Exception as e:
            write(''.join(traceback.format_stack()))
            write(e)
            exit(1)
    return parse_args


def handle_error(params):
    def parse_args(self: ArgumentParser, args=None, namespace=None):
        raise NotImplementedError
    return parse_args


def handle_field_update(params):
    def parse_args(self: ArgumentParser, args=None, namespace=None):
        raise NotImplementedError
    return parse_args


def handle_submit(params):
    def parse_args(self: ArgumentParser, args=None, namespace=None):
        raise NotImplementedError
    return parse_args


def choose_hander(params: GooeyParams, cliargs: List[str]):
    """
    Dispatches to the appropriate handler based on values
    found in the CLI arguments
    """
    with open('tmp.txt', 'w') as f:
        f.write(str(sys.argv))
    if '--gooey-validate-form' in cliargs:
        return validate_form(params)
    elif '--gooey-run-is-success' in cliargs or '--gooey-run-is-failure' in cliargs:
        return handle_completed_run(params)
    elif '--ignore-gooey' in cliargs:
        return bypass_gooey(params)
    else:
        return boostrap_gooey(params)






from argparse import _StoreAction

from gooey import Gooey, GooeyParser
from python_bindings.control import Gooey1


def foo(*args):
    return [1,2,3]


def mything(x):
    raise Exception('Nope!!!!')

class MyAction(_StoreAction):
    def __call__(self, *args, **kwargs):
        # print('Hello!!!')
        super(MyAction, self).__call__(*args, **kwargs)


@Gooey
def main():
    parser = GooeyParser()
    subs = parser.add_subparsers()
    curl = subs.add_parser('curl')
    subgroup = curl.add_argument_group('Super cool group')
    subgroup.add_argument(
        '-foo',
        metavar='Hello World!',
        help='I am a helpful message!')

    ffmpeg = subs.add_parser('ffmpeg')
    subgroup2 = ffmpeg.add_argument_group('Super cool group2')
    subgroup2.add_argument(
        '-foob',
        metavar='Hello World Again!',
        help='I am a helpful message!')

    parser.parse_args()



if __name__ == '__main__':
    main()


from contextlib import contextmanager

import time
from threading import Thread
from typing import Tuple

import wx

from gooey.gui import bootstrap
from gooey.python_bindings.config_generator import create_from_parser
from gooey.python_bindings.parameters import gooey_params
from gooey.util.functional import merge
from gooey.gui.application.application import RGooey


@contextmanager
def instrumentGooey(parser, **kwargs) -> Tuple[wx.App, wx.Frame, RGooey]:
    """
    Context manager used during testing for setup/tear down of the
    WX infrastructure during subTests.

    Weirdness warning: this uses a globally reused wx.App instance.
    """
    from gooey.tests import app
    if app == None:
        raise Exception("App instance has not been created! This is likely due to "
                        "you forgetting to add the magical import which makes all these "
                        "tests work. See the module doc in gooey.tests.__init__ for guidance")
    buildspec = create_from_parser(parser, "", **gooey_params(**kwargs))
    app, frame = bootstrap._build_app(buildspec, app)
    app.SetTopWindow(frame)
    try:
        # we need to run the main loop temporarily to get it to
        # apply any pending updates from the initial creation.
        # The UI state will be stale otherwise
        # this works because CallLater just enqueues the message to
        # be processed. The MainLoop starts running, picks it up, and
        # then exists
        wx.CallLater(1, app.ExitMainLoop)
        app.MainLoop()
        yield (app, frame, frame._instance)
    finally:
        frame.Destroy()
        del frame



import argparse
import pandas as pd


from gooey import Gooey, GooeyParser
import wx

df = pd.read_csv(
        index_col=None,
        header=None,
        error_bad_lines=False,
        sep=",",
        warn_bad_lines=False,
    )

# @Gooey(clear_before_run=True)
# def main():
#     settings_msg = 'Example'
#     parser = GooeyParser(description=settings_msg)
#
#     args=parser.parse_args()
#     print("Howdy")
#     xs = ['1.0.7', '1.0.8.1', '1.0.8', '1.0.9', '1.0.7.1']
#     print(sorted(xs))

if __name__ == '__main__':
    main()





from textwrap import dedent

from gooey import Gooey, GooeyParser


@Gooey(program_name='My Super Awesome Program',
       default_size=(670, 615),
       header_show_title=True,
       dump_build_config=True,
       menu=[{
           'name': 'Help',
           'items': [{
               'type': 'Link',
               'menuTitle': 'Visit Our Site',
               'url': 'https://github.com/chriskiehl/Gooey'
           }, {
               'type': 'MessageDialog',
               'menuTitle': 'Visit Our Site',
               'message': 'Hello world!!!!'
           }, {
               'type': 'HtmlDialog',
               'menuTitle': 'Fancy About',
               'caption': 'Custom Dialog with basic HTML support',
               'html': dedent(r'''
                            <div align="center">
                                <img width="60" height="60" src="C:\Users\Chris\Documents\Gooey\gooey\images\config_icon.png" /> 
                            </div>
                            
                           <h2>Hello there!</h2>
                           <p><font color="red">I am </font>  
                           <font color="blue">some </font>
                           <font color="green">custom</font>
                           <font color="purple">html!</font>  
                           '''),
           }]
       }]
       )
def main():
    '''
    Dummy Function to create a gooey GUI and test the issue.
    '''
    parser = GooeyParser(
        description='This is my program.\nThere are many like it, but this one is mine.')
    parser.add_argument('myfolder', widget='DirChooser',
                        help='Path to directory where output will be stored.')
    args = parser.parse_args()

    print('I\'m a dummy!')


main()


from gooey import GooeyParser, Gooey



def main():
    parser = GooeyParser()
    subs = parser.add_subparsers()
    foo = subs.add_parser('foo')
    foo.add_argument('a')
    foo.add_argument('b')
    foo.add_argument('p')

    bar = subs.add_parser('bar')
    bar.add_argument('a')
    bar.add_argument('b')
    bar.add_argument('z')
    parser.parse_args(['foo'])


main()


from gooey import GooeyParser, Gooey


@Gooey(show_sidebar=True)
def main():
    parser = GooeyParser()
    search_options = parser.add_argument_group('Search Options', 'Customize the search options',
                                               gooey_options={
                                                   'show_border': True,
                                                   'columns': 2})
    search_options.add_argument('--query', help='base search string')
    search_options.add_argument('--query2', help='base search string')
    search_flags = search_options.add_argument_group('Flags',
                                                     gooey_options={'show_border': True}
                                                     )

    search_flags.add_argument('--buy-it-now', help="Will immediately purchase if possible")
    search_flags.add_argument('--auction', help="Place bids up to PRICE_MAX")

    foobar = search_options.add_mutually_exclusive_group(
        gooey_options={'title': 'foobar',
                       'show_border': True,
                       'label_color': '#00ff00'}
    )
    foobar.add_argument('--snortRule', help='oneie')
    foobar.add_argument('--mtxRule', help='twoie')
    foobar.add_argument('--three', help='twoie')

    parser.parse_args()


if __name__ == '__main__':
    main()


import argparse
from gooey import Gooey

@Gooey
def process_options():
    parser = argparse.ArgumentParser()
    parser.add_argument("--grids", type=str, help='top x%% of data')
    return parser.parse_args(['-h'])

args = process_options()


from argparse import ArgumentParser
from gooey import Gooey, GooeyParser
import time
from time import sleep
import signal
import sys
import argparse



@Gooey()
def main():
    parser = GooeyParser(description='Process some data.')
    parser.add_argument('required_field1', metavar='Some Field 1', type=argparse.FileType(encoding="UTF-8"), help='Enter some numbers!')
    parser.add_argument('required_field2', metavar='Some Field 2', help='Enter some text!')
    parser.add_argument('required_field3', metavar='Some Option', help='Select a Option', widget='Dropdown', choices=['a', 'b', 'c'])
    parser.add_argument('-f', '--foo', metavar='Some Flag', action='store_true', help='I turn things on and off')
    parser.add_argument(
        "-v", "--something",
        metavar="* Something",
        help="Anything",
        default=1.0,
        widget="DecimalField")
    parser.parse_args()



if __name__ == '__main__':
    main()


from gooey import Gooey, GooeyParser, options


@Gooey(tabbed_groups=True, navigation='SIDEBAR')
def main():
    parser = GooeyParser()
    sub = parser.add_subparsers(dest='ssss')

    # Main TABs
    parser = sub.add_parser('options',
                            prog="Options")

    parent = parser.add_argument_group('Search Options', gooey_options=options.ArgumentGroup(columns=1))
    parent.add_argument('--query-string', help='the search string')

    child_one = parent.add_argument_group('flags',
                                          gooey_options={'show_border': True, 'columns': 2})
    child_one.add_argument('--option1', help='some text here')
    child_one.add_argument('--option3', help='some text here3', gooey_options={'full_width': True})
    child_one.add_argument('--option34', help='some text here3', gooey_options={'full_width': True})
    child_one.add_argument('--option224', help='some text here3',
                           gooey_options={'full_width': True})
    child_one.add_argument('--option24', help='some text here3', gooey_options={'full_width': True})

    child_two = parent.add_argument_group('price', gooey_options={'show_border': True})
    child_two.add_argument('--option2333', help='some text here')

    child_3 = parent.add_argument_group('price', gooey_options={'show_border': True})
    child_3.add_argument('--option333345', help='some text here')

    child_4 = parent.add_argument_group('price', gooey_options={'show_border': True})
    child_4.add_argument('--option333ssss345', help='some text here')

    parent2 = parser.add_argument_group('Search Options2', gooey_options={
        'columns': 3
    })
    parent2.add_argument('--query-string2', help='the search string')

    args = parser.parse_args()

if __name__ == '__main__':
    main()



'''
Main runner entry point for Gooey.
'''
from typing import Any, Tuple

import wx  # type: ignore
# wx.html and wx.xml imports required here to make packaging with
# pyinstaller on OSX possible without manually specifying `hidden_imports`
# in the build.spec
import wx.html  # type: ignore
import wx.lib.inspection  # type: ignore
import wx.richtext  # type: ignore
import wx.xml  # type: ignore

from gooey.gui import image_repository
from gooey.gui.application.application import RGooey
from gooey.gui.lang import i18n
from gooey.util.functional import merge
from rewx import render, create_element  # type: ignore


def run(build_spec):
    app, _ = build_app(build_spec)
    app.MainLoop()


def build_app(build_spec):
    app = wx.App(False)
    return _build_app(build_spec, app)


def _build_app(build_spec, app) -> Tuple[Any, wx.Frame]:
    """
    Note: this method is broken out with app as
    an argument to facilitate testing.
    """
    # use actual program name instead of script file name in macOS menu
    app.SetAppDisplayName(build_spec['program_name'])

    i18n.load(build_spec['language_dir'], build_spec['language'], build_spec['encoding'])
    imagesPaths = image_repository.loadImages(build_spec['image_dir'])
    gapp2 = render(create_element(RGooey, merge(build_spec, imagesPaths)), None)
    # wx.lib.inspection.InspectionTool().Show()
    # gapp.Show()
    gapp2.Show()
    return (app, gapp2)



from collections import namedtuple

SIDEBAR = 'SIDEBAR'
TABBED = 'TABBED'
INLINE = 'INLINE'
HIDDEN = 'HIDDEN'

FONTWEIGHT_THIN = 100
FONTWEIGHT_EXTRALIGHT = 200
FONTWEIGHT_LIGHT = 300
FONTWEIGHT_NORMAL = 400
FONTWEIGHT_MEDIUM = 500
FONTWEIGHT_SEMIBOLD = 600
FONTWEIGHT_BOLD = 700
FONTWEIGHT_EXTRABOLD = 800
FONTWEIGHT_HEAVY = 900
FONTWEIGHT_EXTRAHEAVY = 1000


Events = namedtuple('Events', [
    'VALIDATE_FORM', 'ON_SUCCESS', 'ON_ERROR'
])('VALIDATE_FORM', 'ON_SUCCESS', 'ON_ERROR')

# class Events:
#     VALIDATE_FORM = 'VALIDATE_FORM'
#     ON_SUCCESS = 'ON_SUCCESS'
#     ON_ERROR = 'ON_ERROR'




from argparse import ArgumentParser
from gooey import Gooey, GooeyParser
import time
from time import sleep
import signal
import sys

running = [True]


@Gooey(progress_regex=r"^progress: (\d+)%$",
       show_stop_warning=False,
       hide_progress_msg=True,
       disable_progress_bar_animation=True
       )
def main():
    parser = GooeyParser(prog="example_progress_bar_1")
    _ = parser.parse_args(sys.argv[1:])

    for i in range(100):
        print("progress: {}%".format(i + 1))
        sys.stdout.flush()
        sleep(0.1)


if __name__ == "__main__":
    sys.exit(main())